@@ -109,7 +109,7 @@ odbcListObjects.OdbcConnection <- function(connection, catalog = NULL, schema =
     }
   }
 
-  objs <- tryCatch(connection_sql_tables(connection@ptr, catalog, schema, name, type), error = function(e) NULL)
+  objs <- tryCatch(connection_sql_tables(connection@ptr, catalog, schema, name, table_type = type), error = function(e) NULL)
   # just return a list of the objects and their types, possibly filtered by the
   # options above
   data.frame(
@@ -148,6 +148,12 @@ computeHostName <- function(connection) {
 
 computeDisplayName <- function(connection) {
 
+  # use DSN if present
+  dsn <- connection@info$sourcename
+  if (!is.null(dsn) & dsn != "") {
+    return(dsn)
+  }
+
   # use the database name as the display name
   display_name <- connection@info$dbname
   server_name <- connection@info$servername
@@ -188,8 +194,8 @@ odbcListColumns.OdbcConnection <- function(connection, table = NULL, view = NULL
   # specify schema or catalog if given
   cols <- connection_sql_columns(connection@ptr,
     table_name = validateObjectName(table, view),
-    catalog_name = catalog %||% "",
-    schema_name = schema %||% "")
+    catalog_name = catalog,
+    schema_name = schema)
 
   # extract and name fields for observer
   data.frame(
@@ -329,7 +335,7 @@ odbcConnectionActions.default <- function(connection) {
             }
             tables <- dbListTables(connection)
 
-            documentNew("sql", contents, row = 2, column = columnPos, execute = TRUE)
+            documentNew("sql", contents, row = 2, column = columnPos, execute = FALSE)
           }
         )
       )
